document.addEventListener('DOMContentLoaded', function() {
  // Lazy load videos
  const lazyVideos = document.querySelectorAll('video[data-src]');
  
  const lazyVideoObserver = new IntersectionObserver((entries, observer) => {
    entries.forEach(entry => {
      if (entry.isIntersecting) {
        const video = entry.target;
        video.src = video.getAttribute('data-src');
        video.removeAttribute('data-src');
        observer.unobserve(video);
      }
    });
  }, { rootMargin: '100px' });
  
  lazyVideos.forEach(video => {
    lazyVideoObserver.observe(video);
  });
  
  // Smooth scrolling for anchor links
  document.querySelectorAll('a[href^="#"]').forEach(anchor => {
    anchor.addEventListener('click', function(e) {
      e.preventDefault();
      
      const targetId = this.getAttribute('href');
      if (targetId === '#') return;
      
      const targetElement = document.querySelector(targetId);
      if (targetElement) {
        window.scrollTo({
          top: targetElement.offsetTop - 80,
          behavior: 'smooth'
        });
      }
    });
  });
  
  // Video hover preview
  const videoCards = document.querySelectorAll('.video-card');
  
  videoCards.forEach(card => {
    const video = card.querySelector('video');
    
    card.addEventListener('mouseenter', () => {
      video.currentTime = 0;
      video.play().catch(e => console.log('Autoplay prevented:', e));
    });
    
    card.addEventListener('mouseleave', () => {
      video.pause();
    });
  });
});